{{/*
Полное имя приложения создается по правилу <имя helm-charts>-<имя инстанса>
<Имя инстанса> = Release.Name
*/}}
{{- define "msghandler.fullname" -}}
{{- printf "%s-%s" .Chart.Name .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "msghandler.labels" -}}
helm.sh/chart: {{ include "msghandler.chart" . }}
{{ include "msghandler.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "msghandler.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "msghandler.selectorLabels" -}}
app.kubernetes.io/instance: {{ .Release.Name }}
app: {{ include "msghandler.fullname" . }}
run: inspark
{{- end }}

{{/*
ServiceAccount задается для контейнеров msghandler-artemis, которые должны работать в кластерном режиме
*/}}
{{- define "msghandler.serviceAccountName" -}}
{{- default (printf "%s-%s" .Values.serviceAccount.name .Release.Name) }}
{{- end }}

{{/*
Имя configMap jms artemis
*/}}
{{- define "msghandler.msghandler-config" -}}
{{- printf "%s-%s" (include "msghandler.serviceAccountName" .) "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя configMap для кластера jgroups
*/}}
{{- define "msghandler.jgroups-config" -}}
{{- printf "%s-%s-%s" "jgroups" .Chart.Name "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя config-standalone-full для msghandler
*/}}
{{- define "semnext.msghandler-standalone-full" -}}
{{- printf "%s-%s" "standalone-full-handler" .Release.Name  | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}


{{/*
Return  the proper Storage Class
*/}}
{{- define "msghandler.storageClass" -}}
  {{- if .Values.persistence.storageClass -}}
      {{- if (eq "-" .Values.persistence.storageClass) -}}
          {{- printf "storageClassName: \"\"" -}}
      {{- else }}
          {{- printf "storageClassName: %s" .Values.persistence.storageClass -}}
      {{- end -}}
  {{- end -}}
{{- end -}}

{{/*
Задаем replica
*/}}
{{- define "msghandler.replicaQuote" -}}

{{- if eq .Values.global.replicaQuote.quoteClass "large" -}}
  {{- .Values.replicaCount.largeQuota_handler -}}
{{- else -}}
  {{- if eq .Values.global.replicaQuote.quoteClass "middle" -}}
    {{- .Values.replicaCount.middleQuota_handler -}}
  {{- else -}}
    {{- .Values.replicaCount.miniQuota_handler -}}
  {{- end -}}
{{- end -}}

{{- end -}}
